@@ -1163,7 +1163,7 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   // 
   WorkgroupPtr workgroup = findWorkgroup(share->workgroupName());
   
-  if ((workgroup && !workgroup->dnsDiscovered()) && !share->workgroupName().isEmpty())
+  if ((workgroup && !workgroup->dnsDiscovered()) || (!workgroup && !share->workgroupName().trimmed().isEmpty()))
   {
     argumentsList << QString("domain=%1").arg(KShell::quoteArg(share->workgroupName()));
   }
@@ -1714,7 +1714,7 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   // 
   WorkgroupPtr workgroup = findWorkgroup(share->workgroupName());
   
-  if ((workgroup && !workgroup->dnsDiscovered()) && !share->workgroupName().isEmpty())
+  if ((workgroup && !workgroup->dnsDiscovered()) || (!workgroup && !share->workgroupName().trimmed().isEmpty()))
   {
     argumentsList << "-W";
     argumentsList << KShell::quoteArg(share->workgroupName());
